P4 to Git Change 2009236 by eshcherb@evgeny-hip on 2019/10/07 11:49:55
SWDEV-197287 - HIP tracing layer instrumentation hip_prof_str.h - generated header; as a next step a genrator will be integrated in HIP makefile (similar to HIP-HCC) prof_protocol.h - temporarily included in HIP sources. Provided by roctracer-proto package. HIP-HCC CMake has parameter to set a path to the header. Affected files ... ... //depot/stg/opencl/drivers/opencl/api/hip/build/Makefile.hip#23 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_context.cpp#23 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_device.cpp#24 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_device_runtime.cpp#19 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_error.cpp#3 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_event.cpp#17 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_intercept.cpp#1 add ... //depot/stg/opencl/drivers/opencl/api/hip/hip_internal.hpp#44 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_memory.cpp#74 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_module.cpp#43 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_peer.cpp#7 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_platform.cpp#44 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_prof_api.h#1 add ... //depot/stg/opencl/drivers/opencl/api/hip/hip_profile.cpp#3 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_stream.cpp#25 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_surface.cpp#5 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_texture.cpp#21 edit ... //depot/stg/opencl/drivers/opencl/api/hip/prof_protocol.h#1 add ... //depot/stg/opencl/drivers/opencl/hip_prof_gen.py#1 add ... //depot/stg/opencl/drivers/opencl/make/hip.git/include/hip/hcc_detail/hip_prof_str.h#2 delete
This commit is contained in:
@@ -182,19 +182,19 @@ hipError_t ihipEventQuery(hipEvent_t event) {
|
||||
}
|
||||
|
||||
hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags) {
|
||||
HIP_INIT_API(event, flags);
|
||||
HIP_INIT_API(hipEventCreateWithFlags, event, flags);
|
||||
|
||||
HIP_RETURN(ihipEventCreateWithFlags(event, flags));
|
||||
}
|
||||
}
|
||||
|
||||
hipError_t hipEventCreate(hipEvent_t* event) {
|
||||
HIP_INIT_API(event);
|
||||
HIP_INIT_API(hipEventCreate, event);
|
||||
|
||||
HIP_RETURN(ihipEventCreateWithFlags(event, 0));
|
||||
}
|
||||
|
||||
hipError_t hipEventDestroy(hipEvent_t event) {
|
||||
HIP_INIT_API(event);
|
||||
HIP_INIT_API(hipEventDestroy, event);
|
||||
|
||||
if (event == nullptr) {
|
||||
HIP_RETURN(hipErrorInvalidResourceHandle);
|
||||
@@ -206,7 +206,7 @@ hipError_t hipEventDestroy(hipEvent_t event) {
|
||||
}
|
||||
|
||||
hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop) {
|
||||
HIP_INIT_API(ms, start, stop);
|
||||
HIP_INIT_API(hipEventElapsedTime, ms, start, stop);
|
||||
|
||||
if (start == nullptr || stop == nullptr) {
|
||||
HIP_RETURN(hipErrorInvalidResourceHandle);
|
||||
@@ -223,7 +223,7 @@ hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop) {
|
||||
}
|
||||
|
||||
hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream) {
|
||||
HIP_INIT_API(event, stream);
|
||||
HIP_INIT_API(hipEventRecord, event, stream);
|
||||
|
||||
if (event == nullptr) {
|
||||
HIP_RETURN(hipErrorInvalidResourceHandle);
|
||||
@@ -246,7 +246,7 @@ hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream) {
|
||||
}
|
||||
|
||||
hipError_t hipEventSynchronize(hipEvent_t event) {
|
||||
HIP_INIT_API(event);
|
||||
HIP_INIT_API(hipEventSynchronize, event);
|
||||
|
||||
if (event == nullptr) {
|
||||
HIP_RETURN(hipErrorInvalidResourceHandle);
|
||||
@@ -258,7 +258,7 @@ hipError_t hipEventSynchronize(hipEvent_t event) {
|
||||
}
|
||||
|
||||
hipError_t hipEventQuery(hipEvent_t event) {
|
||||
HIP_INIT_API(event);
|
||||
HIP_INIT_API(hipEventQuery, event);
|
||||
|
||||
HIP_RETURN(ihipEventQuery(event));
|
||||
}
|
||||
|
||||
Reference in New Issue
Block a user